@@ -1,4 +1,4 @@
-from dagster._core.utils import check_dagster_package_version
+from dagster._core.libraries import DagsterLibraryRegistry
 
 from .asset_factory import define_dagstermill_asset as define_dagstermill_asset
 from .context import DagstermillExecutionContext as DagstermillExecutionContext
@@ -8,7 +8,7 @@ from .io_managers import local_output_notebook_io_manager as local_output_notebo
 from .manager import MANAGER_FOR_NOTEBOOK_INSTANCE as _MANAGER_FOR_NOTEBOOK_INSTANCE
 from .version import __version__ as __version__
 
-check_dagster_package_version("dagstermill", __version__)
+DagsterLibraryRegistry.register("dagstermill", __version__)
 
 get_context = _MANAGER_FOR_NOTEBOOK_INSTANCE.get_context
 
