@@ -1,15 +1,12 @@
-import os
 import pickle
-import sys
 import tempfile
-import uuid
-from typing import Any, Mapping, Optional, Set, Union
+from typing import Any, Callable, Iterable, Mapping, Optional, Set, Union
 
 import dagster._check as check
-import papermill
 from dagster import (
     AssetIn,
     AssetKey,
+    AssetsDefinition,
     Failure,
     Output,
     PartitionsDefinition,
@@ -21,106 +18,32 @@ from dagster import (
 from dagster._core.definitions.events import CoercibleToAssetKeyPrefix
 from dagster._core.definitions.utils import validate_tags
 from dagster._core.execution.context.compute import OpExecutionContext
-from dagster._core.execution.context.system import StepExecutionContext
-from dagster._utils import safe_tempfile_path
-from dagster._utils.error import serializable_error_info_from_exc_info
-from papermill.engines import papermill_engines
-from papermill.iorw import load_notebook_node, write_ipynb
 
-from dagstermill.compat import ExecutionError
-from dagstermill.factory import (
-    _clean_path_for_windows,
-    get_papermill_parameters,
-    replace_parameters,
-)
-
-from .engine import DagstermillEngine
+from dagstermill.factory import _clean_path_for_windows, execute_notebook
 
 
-def _dm_compute(
+def _make_dagstermill_asset_compute_fn(
     name: str,
     notebook_path: str,
     save_notebook_on_failure: bool,
-):
-    check.str_param(name, "name")
-    check.str_param(notebook_path, "notebook_path")
-
-    def _t_fn(context, **inputs):
-        check.inst_param(context, "context", OpExecutionContext)
+) -> Callable:
+    def _t_fn(context: OpExecutionContext, **inputs) -> Iterable:
         check.param_invariant(
             isinstance(context.run_config, dict),
             "context",
             "StepExecutionContext must have valid run_config",
         )
 
-        step_execution_context: StepExecutionContext = context.get_step_execution_context()
-
         with tempfile.TemporaryDirectory() as output_notebook_dir:
-            with safe_tempfile_path() as output_log_path:
-                prefix = str(uuid.uuid4())
-                parameterized_notebook_path = os.path.join(
-                    output_notebook_dir, f"{prefix}-inter.ipynb"
-                )
-
-                executed_notebook_path = os.path.join(output_notebook_dir, f"{prefix}-out.ipynb")
-
-                # Scaffold the registration here
-                nb = load_notebook_node(notebook_path)
-                compute_descriptor = "asset"
-
-                nb_no_parameters = replace_parameters(
-                    step_execution_context,
-                    nb,
-                    get_papermill_parameters(
-                        step_execution_context,
-                        inputs,
-                        output_log_path,
-                        compute_descriptor,
-                    ),
-                )
-
-                write_ipynb(nb_no_parameters, parameterized_notebook_path)
-
-                try:
-                    papermill_engines.register("dagstermill", DagstermillEngine)
-                    papermill.execute_notebook(
-                        input_path=parameterized_notebook_path,
-                        output_path=executed_notebook_path,
-                        engine_name="dagstermill",
-                        log_output=True,
-                    )
-                except Exception as ex:
-                    step_execution_context.log.warn(
-                        "Error when attempting to materialize executed notebook:"
-                        f" {serializable_error_info_from_exc_info(sys.exc_info())}"
-                    )
-                    # pylint: disable=no-member
-                    # compat:
-                    if isinstance(ex, ExecutionError) and (
-                        ex.ename == "RetryRequested" or ex.ename == "Failure"
-                    ):
-                        step_execution_context.log.warn(
-                            f"Encountered raised {ex.ename} in notebook. Use"
-                            " dagstermill.yield_event with RetryRequested or Failure to trigger"
-                            " their behavior."
-                        )
-
-                    if save_notebook_on_failure:
-                        storage_dir = context.instance.storage_directory()
-                        storage_path = os.path.join(storage_dir, f"{prefix}-out.ipynb")
-                        with open(storage_path, "wb") as dest_file_obj:
-                            with open(executed_notebook_path, "rb") as obj:
-                                dest_file_obj.write(obj.read())
-
-                        step_execution_context.log.info(
-                            f"Failed notebook written to {storage_path}"
-                        )
-
-                    raise
-
-            step_execution_context.log.debug(
-                f"Notebook execution complete for {name} at {executed_notebook_path}."
+            executed_notebook_path = execute_notebook(
+                context.get_step_execution_context(),
+                name=name,
+                inputs=inputs,
+                save_notebook_on_failure=save_notebook_on_failure,
+                notebook_path=notebook_path,
+                output_notebook_dir=output_notebook_dir,
             )
+
             with open(executed_notebook_path, "rb") as fd:
                 yield Output(fd.read())
 
@@ -158,7 +81,7 @@ def define_dagstermill_asset(
     io_manager_key: Optional[str] = None,
     retry_policy: Optional[RetryPolicy] = None,
     save_notebook_on_failure: bool = False,
-):
+) -> AssetsDefinition:
     """Creates a Dagster asset for a Jupyter notebook.
 
     Arguments:
@@ -279,7 +202,7 @@ def define_dagstermill_asset(
         io_manager_key=io_mgr_key,
         retry_policy=retry_policy,
     )(
-        _dm_compute(
+        _make_dagstermill_asset_compute_fn(
             name=name,
             notebook_path=notebook_path,
             save_notebook_on_failure=save_notebook_on_failure,
