@@ -27,9 +27,9 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
         pipeline_context: PlanExecutionContext,
         pipeline_def: PipelineDefinition,
         resource_keys_to_init: AbstractSet[str],
-        solid_name: str,
-        solid_handle: NodeHandle,
-        solid_config: Any = None,
+        op_name: str,
+        node_handle: NodeHandle,
+        op_config: Any = None,
     ):
         self._pipeline_context = check.inst_param(
             pipeline_context, "pipeline_context", PlanExecutionContext
@@ -38,9 +38,9 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
         self._resource_keys_to_init = check.set_param(
             resource_keys_to_init, "resource_keys_to_init", of_type=str
         )
-        self.solid_name = check.str_param(solid_name, "solid_name")
-        self.solid_handle = check.inst_param(solid_handle, "solid_handle", NodeHandle)
-        self._solid_config = solid_config
+        self.op_name = check.str_param(op_name, "op_name")
+        self.node_handle = check.inst_param(node_handle, "node_handle", NodeHandle)
+        self._op_config = op_config
 
     def has_tag(self, key: str) -> bool:
         """Check if a logging tag is defined on the context.
@@ -66,13 +66,13 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
         check.str_param(key, "key")
         return self._pipeline_context.get_tag(key)
 
-    @public  # type: ignore
+    @public
     @property
     def run_id(self) -> str:
         """str: The run_id for the context."""
         return self._pipeline_context.run_id
 
-    @public  # type: ignore
+    @public
     @property
     def run_config(self) -> Mapping[str, Any]:
         """dict: The run_config for the context."""
@@ -83,13 +83,13 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
         """:class:`dagster.ResolvedRunConfig`: The resolved_run_config for the context."""
         return self._pipeline_context.resolved_run_config
 
-    @public  # type: ignore
+    @public
     @property
     def logging_tags(self) -> Mapping[str, str]:
         """dict: The logging tags for the context."""
         return self._pipeline_context.logging_tags
 
-    @public  # type: ignore
+    @public
     @property
     def job_name(self) -> str:
         return self._pipeline_context.job_name
@@ -103,7 +103,7 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
         )
         return self.job_name
 
-    @public  # type: ignore
+    @public
     @property
     def job_def(self) -> JobDefinition:
         """:class:`dagster.JobDefinition`: The job definition for the context.
@@ -141,11 +141,11 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
             required_resource_keys=self._resource_keys_to_init,
         )
 
-    @public  # type: ignore
+    @public
     @property
     def run(self) -> DagsterRun:
         """:class:`dagster.DagsterRun`: The job run for the context."""
-        return cast(DagsterRun, self._pipeline_context.pipeline_run)
+        return cast(DagsterRun, self._pipeline_context.dagster_run)
 
     @property
     def pipeline_run(self) -> DagsterRun:
@@ -164,7 +164,7 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
         """
         return self._pipeline_context.log
 
-    @public  # type: ignore
+    @public
     @property
     def op_def(self) -> OpDefinition:
         """:class:`dagster.OpDefinition`: The op definition for the context.
@@ -172,59 +172,33 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
         In interactive contexts, this may be a dagstermill-specific shim, depending whether an
         op definition was passed to ``dagstermill.get_context``.
         """
-        return cast(OpDefinition, self._pipeline_def.solid_def_named(self.solid_name))
+        return cast(OpDefinition, self._pipeline_def.node_def_named(self.op_name))
 
     @property
-    def solid_def(self) -> OpDefinition:
-        """:class:`dagster.SolidDefinition`: The solid definition for the context.
+    def node(self) -> Node:
+        """:class:`dagster.Node`: The node for the context.
 
-        In interactive contexts, this may be a dagstermill-specific shim, depending whether a
-        solid definition was passed to ``dagstermill.get_context``.
+        In interactive contexts, this may be a dagstermill-specific shim, depending whether an
+        op definition was passed to ``dagstermill.get_context``.
         """
         deprecation_warning(
             "DagstermillExecutionContext.solid_def",
             "0.17.0",
             "use the 'op_def' property instead.",
         )
-        return cast(OpDefinition, self._pipeline_def.solid_def_named(self.solid_name))
+        return self.pipeline_def.get_node(self.node_handle)
 
-    @property
-    def solid(self) -> Node:
-        """:class:`dagster.Node`: The solid for the context.
-
-        In interactive contexts, this may be a dagstermill-specific shim, depending whether a
-        solid definition was passed to ``dagstermill.get_context``.
-        """
-        deprecation_warning(
-            "DagstermillExecutionContext.solid_def",
-            "0.17.0",
-            "use the 'op_def' property instead.",
-        )
-        return self.pipeline_def.get_solid(self.solid_handle)
-
-    @public  # type: ignore
+    @public
     @property
     def op_config(self) -> Any:
         """collections.namedtuple: A dynamically-created type whose properties allow access to
         op-specific config.
         """
-        if self._solid_config:
-            return self._solid_config
+        if self._op_config:
+            return self._op_config
 
-        solid_config = self.resolved_run_config.solids.get(self.solid_name)
-        return solid_config.config if solid_config else None
-
-    @property
-    def solid_config(self) -> Any:
-        """collections.namedtuple: A dynamically-created type whose properties allow access to
-        solid-specific config.
-        """
-        deprecation_warning(
-            "DagstermillExecutionContext.solid_config",
-            "0.17.0",
-            "use the 'op_config' property instead.",
-        )
-        return self.op_config
+        op_config = self.resolved_run_config.ops.get(self.op_name)
+        return op_config.config if op_config else None
 
 
 class DagstermillRuntimeExecutionContext(DagstermillExecutionContext):
@@ -233,17 +207,21 @@ class DagstermillRuntimeExecutionContext(DagstermillExecutionContext):
         pipeline_context: PlanExecutionContext,
         pipeline_def: PipelineDefinition,
         resource_keys_to_init: AbstractSet[str],
-        solid_name: str,
+        op_name: str,
         step_context: StepExecutionContext,
-        solid_handle: NodeHandle,
-        solid_config: Any = None,
+        node_handle: NodeHandle,
+        op_config: Any = None,
     ):
         self._step_context = check.inst_param(step_context, "step_context", StepExecutionContext)
         super().__init__(
             pipeline_context,
             pipeline_def,
             resource_keys_to_init,
-            solid_name,
-            solid_handle,
-            solid_config,
+            op_name,
+            node_handle,
+            op_config,
         )
+
+    @property
+    def step_context(self) -> StepExecutionContext:
+        return self._step_context
