@@ -4,9 +4,8 @@ from papermill.log import logger
 from .compat import ExecutionError, is_papermill_2
 
 if is_papermill_2():
-    # pylint: disable=import-error,no-name-in-module
     from papermill.clientwrap import PapermillNotebookClient
-    from papermill.engines import NBClientEngine  # pylint: disable=import-error
+    from papermill.engines import NBClientEngine
     from papermill.utils import merge_kwargs, remove_args
 
     class DagstermillNotebookClient(PapermillNotebookClient):
@@ -45,7 +44,7 @@ if is_papermill_2():
                 finally:
                     self.nb_man.cell_complete(self.nb.cells[index], cell_index=index)
 
-    class DagstermillEngine(NBClientEngine):
+    class DagstermillEngine(NBClientEngine):  # type: ignore  # (papermill 1 compat)
         @classmethod
         def execute_managed_notebook(
             cls,
@@ -75,10 +74,10 @@ if is_papermill_2():
             return DagstermillNotebookClient(nb_man, **final_kwargs).execute()
 
 else:
-    from papermill.engines import NBConvertEngine  # pylint: disable=import-error,no-name-in-module
-
-    # pylint: disable=import-error,no-name-in-module
-    from papermill.preprocess import PapermillExecutePreprocessor
+    from papermill.engines import NBConvertEngine
+    from papermill.preprocess import (  # type: ignore  # (papermill 1 compat)
+        PapermillExecutePreprocessor,
+    )
 
     class DagstermillExecutePreprocessor(PapermillExecutePreprocessor):
         # We need to finalize dagster resources here (as opposed to, e.g., in the notebook_complete
@@ -110,15 +109,15 @@ else:
 
             return nb_man.nb, resources
 
-    class DagstermillEngine(NBConvertEngine):  # type: ignore[no-redef]
+    class DagstermillEngine(NBConvertEngine):
         @classmethod
         def execute_managed_notebook(
             cls,
             nb_man,
             kernel_name,
             log_output=False,
-            stdout_file=None,  # pylint: disable=unused-argument
-            stderr_file=None,  # pylint: disable=unused-argument
+            stdout_file=None,
+            stderr_file=None,
             start_timeout=60,
             execution_timeout=None,
             **kwargs,
