@@ -56,7 +56,7 @@ class BasicTest:
         self.x = x
 
     def __repr__(self):
-        return "BasicTest: {x}".format(x=str(self.x))
+        return f"BasicTest: {str(self.x)}"
 
 
 def nb_test_path(name):
@@ -261,12 +261,13 @@ def error_job():
 
 
 if DAGSTER_PANDAS_PRESENT and SKLEARN_PRESENT and MATPLOTLIB_PRESENT:
-    clean_data = test_nb_op("clean_data", outs={DEFAULT_OUTPUT: Out(DataFrame)})
+    # We need type-ignores here because type checkers don't understand the `*_PRESENT` kwargs.
+    clean_data = test_nb_op("clean_data", outs={DEFAULT_OUTPUT: Out(DataFrame)})  # type: ignore
 
     # FIXME add an output to this
-    tutorial_LR = test_nb_op("tutorial_LR", ins={"df": In(DataFrame)})
+    tutorial_LR = test_nb_op("tutorial_LR", ins={"df": In(DataFrame)})  # type: ignore
 
-    tutorial_RF = test_nb_op("tutorial_RF", ins={"df": In(DataFrame)})
+    tutorial_RF = test_nb_op("tutorial_RF", ins={"df": In(DataFrame)})  # type: ignore
 
     @job(resource_defs=common_resource_defs)
     def tutorial_job():
