@@ -1,4 +1,5 @@
 import papermill
+import papermill.translators
 from dagster import _seven
 
 RESERVED_INPUT_NAMES = [
@@ -7,7 +8,7 @@ RESERVED_INPUT_NAMES = [
     "__dm_executable_dict",
     "__dm_json",
     "__dm_pipeline_run_dict",
-    "__dm_solid_handle_kwargs",
+    "__dm_node_handle_kwargs",
     "__dm_instance_ref_dict",
     "__dm_step_key",
     "__dm_input_names",
@@ -34,7 +35,7 @@ class DagsterTranslator(papermill.translators.PythonTranslator):
         assert "__dm_context" in parameters
         assert "__dm_executable_dict" in parameters
         assert "__dm_pipeline_run_dict" in parameters
-        assert "__dm_solid_handle_kwargs" in parameters
+        assert "__dm_node_handle_kwargs" in parameters
         assert "__dm_instance_ref_dict" in parameters
         assert "__dm_step_key" in parameters
         assert "__dm_input_names" in parameters
@@ -43,7 +44,7 @@ class DagsterTranslator(papermill.translators.PythonTranslator):
         pipeline_context_args = dict(
             executable_dict=parameters["__dm_executable_dict"],
             pipeline_run_dict=parameters["__dm_pipeline_run_dict"],
-            solid_handle_kwargs=parameters["__dm_solid_handle_kwargs"],
+            node_handle_kwargs=parameters["__dm_node_handle_kwargs"],
             instance_ref_dict=parameters["__dm_instance_ref_dict"],
             step_key=parameters["__dm_step_key"],
             **context_args,
@@ -56,7 +57,7 @@ class DagsterTranslator(papermill.translators.PythonTranslator):
 
         for input_name in parameters["__dm_input_names"]:
             dm_load_input_call = f"__dm_dagstermill._load_input_parameter('{input_name}')"
-            content += "{}\n".format(cls.assign(input_name, dm_load_input_call))
+            content += f"{cls.assign(input_name, dm_load_input_call)}\n"
 
         return content
 
